@@ -1,8 +1,7 @@
 from .analysis import *
 from .plotting import widgets as plot_widgets
 from .plotting import variants as plot_variants
-from .common import utils, configuration
+from .common import __version__, utils, configuration
 from .common.utils import HdfTools
 from .pyqtgraphCore.widgets.MatplotlibWidget import MatplotlibWidget as MPLWidget
-__version__ = '0.2.1'
 __author__ = "Kushal Kolar"
