@@ -98,8 +98,15 @@ class MainWindow(QtWidgets.QMainWindow):
                         'suite2p_importer': suite2p.ModuleGUI,
                         'stimulus_mapping': stimulus_mapping.ModuleGUI,
                         'script_editor': script_editor.ModuleGUI,
+                        'mesc_importer': femtonics_mesc.ModuleGUI,
+                        'exporter': exporter.ModuleGUI,
                         }
 
+    if configuration.HAS_TENSORFLOW:
+        standard_modules.update(
+            {'nuset_segment': nuset_segment.ModuleGUI}
+        )
+
     # caiman modules
     if configuration.HAS_CAIMAN:
         standard_modules.update(
@@ -121,13 +128,18 @@ class MainWindow(QtWidgets.QMainWindow):
         self.ui.setupUi(self)
         self.running_modules = []
         # TODO: Integrate viewer initiation here instead of outside
-        self.ui.actionMesfile.triggered.connect(lambda: self.run_module(mesfile_io.ModuleGUI))
+        self.ui.action_mes_importer.triggered.connect(lambda: self.run_module(mesfile_io.ModuleGUI))
+        self.ui.action_mesc_importer.triggered.connect(lambda: self.run_module(femtonics_mesc.ModuleGUI))
         self.ui.actionTiff_file.triggered.connect(lambda: self.run_module(tiff_io.ModuleGUI))
         self.ui.actionROI_Manager.triggered.connect(lambda: self.run_module(roi_manager.ModuleGUI))
         self.ui.actionSuite2p_Importer.triggered.connect(lambda: self.run_module(suite2p.ModuleGUI))
         self.ui.actionStimulus_Mapping.triggered.connect(lambda: self.run_module(stimulus_mapping.ModuleGUI))
         self.ui.actionScript_Editor.triggered.connect(lambda: self.run_module(script_editor.ModuleGUI))
 
+        if configuration.HAS_TENSORFLOW:
+            self.ui.actionNuSeT_Segmentation.triggered.connect(lambda: self.run_module(nuset_segment.ModuleGUI))
+
+
         # TODO: refactor the actions trigger connections so they're automated based on module name
         if configuration.HAS_CAIMAN:
             self.ui.actionCNMF.triggered.connect(lambda: self.run_module(cnmf.ModuleGUI))
@@ -199,6 +211,10 @@ class MainWindow(QtWidgets.QMainWindow):
         self.run_module(roi_manager.ModuleGUI, hide=True)
         self.roi_manager = self.running_modules[-1]
 
+        self._viewer.ui.btnExportWorkEnv.clicked.connect(
+            partial(self.run_module, 'exporter')
+        )
+
         status_label = self.statusBar()
 
         self._viewer.status_bar_label = status_label
@@ -268,7 +284,7 @@ class MainWindow(QtWidgets.QMainWindow):
         else:
             self.running_modules[-1].hide()
 
-        if (module_class in self.standard_modules.values()) and dock_widget_area.keys():
+        if (module_class in self.standard_modules.values()) and (module_class in dock_widget_area.keys()):
             self.addDockWidget(dock_widget_area[module_class], m)
 
         return self.running_modules[-1]
