@@ -307,9 +307,8 @@ class Output:
                     load_dict_from_hdf5(
                         os.path.join(batch_path, f'{UUID}_results_z{z}.hdf5')
                     )
-                    for z in range(5)
-                    # for z in range(
-                    # vi.viewer.workEnv.imgdata.z_max + 1)
+                    # for z in range(5)
+                    for z in range(vi.viewer.workEnv.imgdata.z_max + 1)
                 ]
 
             manager.add_all_components(
